kernel_block_index_get_previous

Function kernel_block_index_get_previous 

pub unsafe extern "C" fn kernel_block_index_get_previous(
    block_index: *const kernel_BlockIndex,
) -> *mut kernel_BlockIndex
@brief Returns the previous block index in the chain, or null if the current block index entry is the genesis block.

@param[in] block_index Non-null. @return The previous block index, or null on error or if the current block index is the genesis block.