pub unsafe extern "C" fn kernel_logging_set_level_category(
category: kernel_LogCategory,
level: kernel_LogLevel,
)Expand description
@brief Set the log level of the global internal logger. This does not enable the selected categories. Use @ref kernel_logging_enable_category to start logging from a specific, or all categories. This function is not thread safe. Mutiple calls from different threads are allowed but must be synchronized. This changes a global setting and will override settings for all existing @ref kernel_LoggingConnection instances.
@param[in] category If kernel_LOG_ALL is chosen, all messages at the specified level will be logged. Otherwise only messages from the specified category will be logged at the specified level and above. @param[in] level Log level at which the log category is set.