pub unsafe extern "C" fn kernel_chainstate_manager_options_set_wipe_dbs(
chainstate_manager_options: *mut kernel_ChainstateManagerOptions,
wipe_block_tree_db: bool,
wipe_chainstate_db: bool,
) -> boolExpand description
@brief Sets wipe db in the options. In combination with calling @ref kernel_chainstate_manager_import_blocks this triggers either a full reindex, or a reindex of just the chainstate database.
@param[in] chainstate_manager_options Non-null, created by @ref kernel_chainstate_manager_options_create. @param[in] wipe_block_tree_db Set wipe block tree db. Should only be True if wipe_chainstate_db is True too. @param[in] wipe_chainstate_db Set wipe chainstate db. @return True if the set was successful, False if the set failed.